<?php
header('Content-Type: text/html');
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=no">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>365FarmNet Connect</title>
    <link rel="shortcut icon" href="favicon.ico" />
    <link rel="stylesheet" href="styles.css">
</head>

<body>
    <div style="background-color: #E8AD02; width: 100%; text-align: center; padding: 20px; font-size: 20px; margin-bottom: 20px;">
        <a style="color: #000;" target="_blank" href="https://developer.365farmnet.com/site/apps/fn-connect-php/">
            Project source code
        </a>
    </div>
    <?php
    require __DIR__ . '/vendor/autoload.php';

    use \Firebase\JWT\JWT;

    // your partner credentials with stage-specific secrets
    $partners = array(
        '5726c2cf-143b-4834-aa54-24a1c1516a48' => array(
            'development' => 'trsL26xTtFXgPHBJE8n4ZrN6R7fWfLrK',
            'production' => 'trsL26xTtFXgPHBJE8n4ZrN6R7fWfLrK'
        ) // developer
    );

    // the Connect-Token is added to your application's URL within the platform
    if (isset($_REQUEST['jwt'])) {

        $connect_token = $_REQUEST['jwt'];

        // the Connect-Token is a JWT having 3 parts
        list($header_part, $payload_part, $signature_part) = explode(".", $connect_token);
        $connect_payload = json_decode(base64_decode($payload_part), true);

        // the Connect-Token contains specific data and can be used to avoid hard coded URLs
        $api_base = $connect_payload['fn-ext']['apiBase'];
        $fun_level = $connect_payload['fn-ext']['functionalityLevel'];

        // it is important for your application to be aware of our different stages
        $stage = 'development';
        if ($api_base === 'https://connect.365farmnet.com' || $api_base === 'https://pp-connect.365farmnet.com') {
            $stage = 'production';
        }

        // we suggest validating the Connect-Token to make sure it has been created by us
        $public_key = file_get_contents(__DIR__ . '/365FarmNet_Connect-API_public_key_' . $stage . '.pem');

        try {
            $decoded = JWT::decode($connect_token, $public_key, array('RS256'));
        } catch (Exception $e) {
            $error_msg = 'The Connect-Token found in your URL is invalid!';
        }

        if (isset($decoded)) {

            // the azp-field contains the partner id the token is valid for
            $partner_id = $connect_payload['azp'];
            $partner_secret = $partners[$partner_id][$stage];

            // creating the Partner-Token based on your credentials
            $header = array(
                'ver' => '0.1',
                'type' => 'partner'
            );
            $payload = array(
                'con' => $connect_token, // this will also be validated by us
                'iss' => $partner_id
            );

            $partner_token = JWT::encode($payload, $partner_secret, 'HS256', null, $header);

            // accessing one of our APIs using your Partner-Token
            $url = $api_base . '/connect/v1/fields';
            $opts = [
                'http' => [
                    'method' => 'GET',
                    'header' => "Authorization: Bearer {$partner_token}\r\n"
                ]
            ];

            try {
                $context = stream_context_create($opts);
                $contents = file_get_contents($url, false, $context);
                $fields = count(json_decode($contents, true));
            } catch (Exception $e) {
                $error_msg = 'Reading the account\'s fields has failed.';
            }
        }
    } else {
        $error_msg = 'There is no Connect-Token in your URL.';
    }
    ?>
    <div class="error <?php echo (isset($error_msg) ? 'show' : 'hide'); ?>">
        <?php echo $error_msg; ?>
    </div>
    <div class="fl <?php echo (isset($fun_level) ? $fun_level : 'none'); ?> <?php echo (isset($error_msg) ? 'hide' : 'show'); ?>">
        <?php
        // it is possible to check whether the user already bought the application or not
        if ($fun_level == 'test') {
            echo ("You are testing this application for 10 days.");
        } else {
            echo ("You purchased this application and enjoy full access to its features!");
        }
        ?>
    </div>
    <div class="fields <?php echo (isset($error_msg) ? 'hide' : 'show'); ?>">
        <?php
        if (isset($fields) && $fields > 1) {
            echo ('There are ' . $fields . ' fields in your account.');
        } else if (isset($fields) && $fields == 1) {
            echo ('There is 1 field in your account.');
        } else if (!isset($fields) || $fields == 0) {
            echo ('There are no fields in your account.');
        }
        ?>
    </div>
</body>

</html>
